@@ -22,9 +22,10 @@ use Rose::Object::MakeMethods::Generic (
     'scalar --get_set_init' => 'base_code',
     'scalar --get_set_init' => 'base_form_class_code',
     'scalar --get_set_init' => 'text_field_size',
+    'scalar --get_set_init' => 'limit_to_schemas',
 );
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 NAME
 
@@ -167,7 +168,25 @@ The return value is inserted into the base RHTMLO class created;
 
 =cut
 
-sub init_base_form_class_code {''}
+sub init_base_form_class_code {
+    return <<EOF
+use base qw( Rose::HTML::Form );
+
+EOF
+}
+
+=head2 init_limit_to_schemas
+
+The default return value is an empty arrayref, which is interpreted
+as "all schemas" if the B<find_schemas> flag is true.
+
+Otherwise, you may explicitly name an array of schema names to limit
+the code generated to only those schemas you want. B<Must> be used
+with B<find_schemas> set to true.
+
+=cut
+
+sub init_limit_to_schemas { [] }
 
 =head2 plant( I<path> )
 
@@ -256,7 +275,7 @@ EOF
 
     # find all schemas if this db supports them
     my %schemas;
-    if ( $self->find_schemas ) {
+    if ( $self->find_schemas and !scalar @{ $self->limit_to_schemas } ) {
         my %native = ( information_schema => 1, pg_catalog => 1 );
         my $info = $db->dbh->table_info( undef, '%', undef, 'TABLE' )
             ->fetchall_arrayref;
@@ -272,6 +291,17 @@ EOF
         $self->_make_file( join( '::', $garden_prefix, 'Metadata' ),
             $self->_metadata_template );
 
+    }
+
+    # if we are using schemas and have explicitly named them already,
+    # then use what was specified.
+    elsif ( $self->find_schemas ) {
+
+        $schemas{$_}++ for @{ $self->limit_to_schemas };
+
+        $self->_make_file( join( '::', $garden_prefix, 'Metadata' ),
+            $self->_metadata_template );
+
     }
     else {
 
@@ -378,17 +408,17 @@ EOF
 
     # first create the base ::Form class.
     my $base_form_class = join( '::', $garden_prefix, 'Form' );
-    my $base_form_class_code = $self->base_form_class_code || '';
+    my $base_form_class_code = $self->base_form_class_code;
     my $base_form_template = <<EOF;
 package $base_form_class;
 use strict;
-use base qw( Rose::HTML::Form );
 
 $base_form_class_code
 
-sub garden_prefix { '$garden_prefix' }
-
 1;
+
+# generated by Rose::DBx::Garden
+
 EOF
 
     $self->_make_file( $base_form_class, $base_form_template );
@@ -456,12 +486,6 @@ package $form_class;
 use strict;
 use base qw( $base_form_class );
 
-use Rose::HTMLx::Form::Field::Boolean;
-use Rose::HTMLx::Form::Field::Autocomplete;
-
-__PACKAGE__->field_type_classes->{boolean}      = 'Rose::HTMLx::Form::Field::Boolean';
-__PACKAGE__->field_type_classes->{autocomplete} = 'Rose::HTMLx::Form::Field::Autocomplete';
-
 sub object_class { '$rdbo_class' }
 
 sub init_with_${object_name} {
@@ -540,7 +564,7 @@ sub garden_default_field {
     my $type     = $self->column_field_map->{$col_type} || 'text';
     my $name     = $column->name;
     my $length   = $column->can('length') ? $column->length() : 0;
-    $length = 24 unless defined $length;  # 24 holds a timestamp
+    $length = 24 unless defined $length;    # 24 holds a timestamp
     my $maxlen = $self->text_field_size;
 
     if ( $length > $maxlen ) {
